==> wizzi-core-0.7.3.tgz: package/readme.md <==
# wizzi-core

A Wizzi plugin with core schemas and artifact generators. This plugin is integrated in the Wizzi API..

## Work still in progress

Availability of features will be announced
on [Twitter](https://twitter.com/wizziteam) and [Facebook](https://www.facebook.com/wizzifactory)

## Features
### Implemented Wizzi models

<table>
<tr>
<th>Schema</th>
<th>Descriptionn</th>
<th>Builtin</th>
<th>Model transformers</th>
<th>Artifacts</th>
</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/wizzi-core/.wizzi/ittf/lib/wizzi/schemas/wfjob.wfschema.ittf>wfjob</a><td>Wizzi job definition</td>
<td>
no<td>

<table>
</table>

<td>

<table>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/wizzi-core/.wizzi/ittf/lib/wizzi/schemas/wfschema.wfschema.ittf>wfschema</a><td>Wizzi schema definition</td>
<td>
no<td>

<table>
<tr>
<td>wfschema/json_docs</td>
</tr>
</table>

<td>

<table>
<tr>
<td>wfschema/factory</td>
</tr>
<tr>
<td>wfschema/model</td>
</tr>
<tr>
<td>wfschema/html_docs</td>
</tr>
<tr>
<td>wfschema/test</td>
</tr>
</table>

</tr>
<tr>
<td>
json<td>json wizzi language model</td>
<td>
yes<td>

<table>
</table>

<td>

<table>
<tr>
<td>json/document</td>
</tr>
<tr>
<td>json/toyaml</td>
</tr>
<tr>
<td>json/toml</td>
</tr>
<tr>
<td>json/export</td>
</tr>
</table>

</tr>
<tr>
<td>
xml<td>xml wizzi language model</td>
<td>
yes<td>

<table>
</table>

<td>

<table>
<tr>
<td>xml/document</td>
</tr>
<tr>
<td>xml/export</td>
</tr>
</table>

</tr>
<tr>
<td>
text<td>text wizzi language model</td>
<td>
yes<td>

<table>
</table>

<td>

<table>
<tr>
<td>text/document</td>
</tr>
</table>

</tr>
<tr>
<td>
ittf<td>ittf wizzi language model</td>
<td>
yes<td>

<table>
<tr>
<td>ittf/cheatsheet</td>
</tr>
<tr>
<td>ittf/html-pretty</td>
</tr>
</table>

<td>

<table>
<tr>
<td>ittf/document</td>
</tr>
<tr>
<td>ittf/tojson</td>
</tr>
</table>

</tr>
<tr>
<td>
yaml<td>yaml wizzi language model</td>
<td>
yes<td>

<table>
</table>

<td>

<table>
<tr>
<td>yaml/document</td>
</tr>
</table>

</tr>
</table>



<p>Wizzi plugins are documented <a href="https://wizzifactory.github.io/docs/wizziplugins.html">here</a>.</p>



<p>You can find a few samples in the /examples folder, but you can find more in the <a href="https://github.com/wizzifactory/wizzi/tree/master/packages/wizzi-demo/.wizzi/ittf/examples/advanced/plugins">demo package</a>.</p>

## Source and generation
wizzi-core is generated using the Wizzi factory ver 0.7

## Wizzi

One machinery, many productions.


<p><a href="https://stfnbssl.github.io/wizzi">Project page</a></p>

## Built With
* [Nodejs](https://nodejs.org)

* [Wizzi Factory](https://github.com/wizzifactory)


## License

<p>This project is licensed under the MIT License - see the <a href="license.txt">license.txt</a> for details.</p>

==> wizzi-core-0.7.8.tgz: package/readme.md <==
# wizzi-core

A Wizzi Plugin with core schemas and artifact generators. This plugin is integrated in the Wizzi API..


## Work still in progress

Availability of features will be announced

on [Twitter](https://twitter.com/wizziteam) and [Facebook](https://www.facebook.com/wizzifactory)


## Features
### Implemented Wizzi Models

<table>
<tr>
<th>Schema</th>
<th>Descriptionn</th>
<th>Builtin</th>
<th>Model transformers</th>
<th>Artifacts</th>
</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/wizzi-core/.wizzi/ittf/lib/wizzi/schemas/wfjob.wfschema.ittf>wfjob</a><td>Wizzi job definition</td>
<td>
no<td>

<table>
</table>

<td>

<table>
</table>

</tr>
<tr>
<td>
<a href https://github.com/wizzifactory/wizzi/blob/master/packages/wizzi-core/.wizzi/ittf/lib/wizzi/schemas/wfschema.wfschema.ittf>wfschema</a><td>Wizzi Schema definition</td>
<td>
no<td>

<table>
<tr>
<td>wfschema/json_docs</td>
</tr>
</table>

<td>

<table>
<tr>
<td>wfschema/factory</td>
</tr>
<tr>
<td>wfschema/model</td>
</tr>
<tr>
<td>wfschema/html_docs</td>
</tr>
<tr>
<td>wfschema/test</td>
</tr>
</table>

</tr>
<tr>
<td>
json<td>json wizzi language model</td>
<td>
yes<td>

<table>
</table>

<td>

<table>
<tr>
<td>json/document</td>
</tr>
<tr>
<td>json/toyaml</td>
</tr>
<tr>
<td>json/toml</td>
</tr>
<tr>
<td>json/export</td>
</tr>
</table>

</tr>
<tr>
<td>
xml<td>xml wizzi language model</td>
<td>
yes<td>

<table>
</table>

<td>

<table>
<tr>
<td>xml/document</td>
</tr>
<tr>
<td>xml/export</td>
</tr>
</table>

</tr>
<tr>
<td>
text<td>text wizzi language model</td>
<td>
yes<td>

<table>
</table>

<td>

<table>
<tr>
<td>text/document</td>
</tr>
</table>

</tr>
<tr>
<td>
ittf<td>ittf wizzi language model</td>
<td>
yes<td>

<table>
<tr>
<td>ittf/cheatsheet</td>
</tr>
<tr>
<td>ittf/html-pretty</td>
</tr>
</table>

<td>

<table>
<tr>
<td>ittf/document</td>
</tr>
<tr>
<td>ittf/tojson</td>
</tr>
</table>

</tr>
<tr>
<td>
yaml<td>yaml wizzi language model</td>
<td>
yes<td>

<table>
</table>

<td>

<table>
<tr>
<td>yaml/document</td>
</tr>
</table>

</tr>
</table>



<p>Wizzi Plugins are documented <a href="https://wizzifactory.github.io/docs/wizziplugins.html">here</a>.</p>



<p>You can find a few samples in the /examples folder, but you can find more in the <a href="https://github.com/wizzifactory/wizzi/tree/master/packages/wizzi-demo/.wizzi/ittf/examples/advanced/plugins">demo package</a>.</p>

## Source and generation
wizzi-core is generated using the Wizzi factory ver 0.7


## Wizzi

One machinery, many productions.



<p><a href="https://stfnbssl.github.io/wizzi">Project page</a></p>

## Built With
* [Nodejs](https://nodejs.org)

* [Wizzi Factory](https://github.com/wizzifactory)


## License

<p>This project is licensed under the MIT License - see the <a href="license.txt">license.txt</a> for details.</p>
